##  Prerequisites
  * Activate the AI agent extension to the meta model. This extension adds the needed entities to your workspace. For details, see [AI Agent Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/ai-agent-extension-to-meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Activate an optional meta model extension to model and govern your organization’s AI agents and MCP servers.").
  * Activate the SAP suggestions in your landscape extension to the meta model. For details, see [SAP Suggestions in Your Landscape Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/sap-suggestions?locale=en-US&state=PRODUCTION&version=CLOUD "Activate an optional extension to the meta model to view SAP suggestions for AI agents and applications in reports.").
  * Link business capabilities to the reference catalog. For details, see [Business Capabilities in the Reference Catalog](https://help.sap.com/docs/leanix/ea/business-capabilities-in-reference-catalog?locale=en-US&version=CLOUD "https://help.sap.com/docs/leanix/ea/business-capabilities-in-reference-catalog?locale=en-US&version=CLOUD").
